@@ -4,14 +4,11 @@ ggeffect <- function(model, terms, ci_level = 0.95, verbose = TRUE, ci.lvl = ci_
   insight::check_if_installed("effects")
   model_name <- deparse(substitute(model))
 
-  # check if terms are a formula
-  if (!missing(terms) && !is.null(terms) && inherits(terms, "formula")) {
-    terms <- all.vars(terms)
-  }
-
-  # "terms" can also be a list, convert now
-  if (!missing(terms) && !is.null(terms)) {
-    terms <- .list_to_character_terms(terms)
+  # process "terms", so we have the default character format. Furthermore,
+  # check terms argument, to make sure that terms were not misspelled and are
+  # indeed existing in the data
+  if (!missing(terms)) {
+    terms <- .reconstruct_focal_terms(terms, model)
   }
 
   ## TODO: add warnings later
@@ -28,35 +25,33 @@ ggeffect <- function(model, terms, ci_level = 0.95, verbose = TRUE, ci.lvl = ci_
 
   if (inherits(model, "list")  && !inherits(model, c("bamlss", "maxLik"))) {
     res <- lapply(model, .ggeffect_helper, terms, ci.lvl = ci_level, verbose, ...)
-  } else {
-    if (missing(terms) || is.null(terms)) {
-      predictors <- insight::find_predictors(
-        model,
-        effects = "fixed",
-        component = "conditional",
-        flatten = TRUE
-      )
-      res <- lapply(
-        predictors,
-        function(.x) {
-          tmp <- .ggeffect_helper(model, terms = .x, ci.lvl = ci_level, verbose, ...)
-          if (!is.null(tmp)) {
-            tmp$group <- .x
-          }
-          tmp
+  } else if (missing(terms) || is.null(terms)) {
+    predictors <- insight::find_predictors(
+      model,
+      effects = "fixed",
+      component = "conditional",
+      flatten = TRUE
+    )
+    res <- lapply(
+      predictors,
+      function(.x) {
+        tmp <- .ggeffect_helper(model, terms = .x, ci.lvl = ci_level, verbose, ...)
+        if (!is.null(tmp)) {
+          tmp$group <- .x
         }
-      )
-      no_results <- vapply(res, is.null, logical(1))
-      res <- .compact_list(res)
-      if (!is.null(res) && !.is_empty(res)) {
-        names(res) <- predictors[!no_results]
-        class(res) <- c("ggalleffects", class(res))
-      } else {
-        res <- NULL
+        tmp
       }
+    )
+    no_results <- vapply(res, is.null, logical(1))
+    res <- .compact_list(res)
+    if (!is.null(res) && !.is_empty(res)) {
+      names(res) <- predictors[!no_results]
+      class(res) <- c("ggalleffects", class(res))
     } else {
-      res <- .ggeffect_helper(model, terms, ci.lvl = ci_level, verbose, ...)
+      res <- NULL
     }
+  } else {
+    res <- .ggeffect_helper(model, terms, ci.lvl = ci_level, verbose, ...)
   }
 
   if (!is.null(res)) {
@@ -68,7 +63,9 @@ ggeffect <- function(model, terms, ci_level = 0.95, verbose = TRUE, ci.lvl = ci_
 
 .ggeffect_helper <- function(model, terms, ci.lvl, verbose = TRUE, ...) {
   # check terms argument
-  original_terms <- terms <- .check_vars(terms, model)
+  original_terms <- terms
+
+  # clean "terms" from possible brackets
   cleaned_terms <- .clean_terms(terms)
 
   # get data, for data grid later
@@ -80,7 +77,7 @@ ggeffect <- function(model, terms, ci_level = 0.95, verbose = TRUE, ci.lvl = ci_
   # check whether we have an argument "transformation" for effects()-function
   # in this case, we need another default title, since we have
   # non-transformed effects
-  additional_dot_args <- lapply(match.call(expand.dots = FALSE)$`...`, function(x) x)
+  additional_dot_args <- match.call(expand.dots = FALSE)[["..."]]
   # check whether we have a "transformation" argument
   t.add <- which(names(additional_dot_args) == "transformation")
   # if we have a "transformation" argument, and it's NULL,
@@ -115,17 +112,15 @@ ggeffect <- function(model, terms, ci_level = 0.95, verbose = TRUE, ci.lvl = ci_
 
   # compute marginal effects for each model term
   eff <- tryCatch(
-    {
-      suppressMessages(suppressWarnings(
-        effects::Effect(
-          focal.predictors = terms,
-          mod = model,
-          xlevels = at_values,
-          confidence.level = ci.lvl,
-          ...
-        )
-      ))
-    },
+    suppressMessages(suppressWarnings(
+      effects::Effect(
+        focal.predictors = terms,
+        mod = model,
+        xlevels = at_values,
+        confidence.level = ci.lvl,
+        ...
+      )
+    )),
     error = function(e) {
       if (verbose) {
         insight::print_color("Can't compute marginal effects, `effects::Effect()` returned an error.\n\n", "red")
